@@ -48,29 +48,30 @@ mods$proportion[is.infinite(mods$proportion)] = 0
 mods$isodecoder = sub(".*_mito_tRNA-", "mito", mods$isodecoder)
 mods$isodecoder = sub(".*_nmt_tRNA-", "nmt", mods$isodecoder)
 mods$isodecoder = sub(".*_tRNA-", "", mods$isodecoder)
-mods$isodecoder = sub(".*_tRX-", "", mods$isodecoder)
+mods$isodecoder = sub(".*_tRX-", "tRX-", mods$isodecoder)
 mods$isodecoder = ifelse(mods$isodecoder == 'eColiLys-TTT-1-1', 'eColiLys', mods$isodecoder)
 mods = mods[!grepl("-", mods$canon_pos), ]
 mods_agg = aggregate(mods$proportion, by = list(isodecoder = mods$isodecoder,
-                                               pos = mods$pos,
-                                               bam = mods$bam,
-                                               condition = mods$condition,
-                                               canon_pos = mods$canon_pos),
-                                               FUN = sum)
+                                                pos = mods$pos,
+                                                bam = mods$bam,
+                                                condition = mods$condition,
+                                                canon_pos = mods$canon_pos),
+                     FUN = sum)
 mods_agg = aggregate(mods_agg$x, by = list(isodecoder = mods_agg$isodecoder,
                                            pos = mods_agg$pos, 
                                            condition = mods_agg$condition,
                                            canon_pos = mods_agg$canon_pos),
-                                           FUN = mean)
+                     FUN = mean)
 
 # read in stops table and process as above for mods
 stops = read.table(paste(out, "mods/RTstopTable.csv", sep = ""),
-                         header = T, sep = "\t", quote = "")
+                   header = T, sep = "\t", quote = "")
 stops$proportion[is.na(stops$proportion)] = 0
 stops$proportion[is.infinite(stops$proportion)] = 0
 stops$isodecoder = sub(".*_mito_tRNA-", "mito", stops$isodecoder)
 stops$isodecoder = sub(".*_nmt_tRNA-", "nmt", stops$isodecoder)
 stops$isodecoder = sub(".*_tRNA-","", stops$isodecoder)
+stops$isodecoder = sub(".*_tRX-", "tRX-", stops$isodecoder)
 stops$isodecoder = ifelse(stops$isodecoder == "eColiLys-TTT-1-1", "eColiLys",
                           stops$isodecoder)
 stops = stops[!grepl("-", stops$canon_pos), ]
@@ -78,15 +79,16 @@ stops_agg = aggregate(stops$proportion, by = list(isodecoder = stops$isodecoder,
                                                   pos = stops$pos,
                                                   condition = stops$condition,
                                                   canon_pos = stops$canon_pos),
-                                                  FUN = mean)
+                      FUN = mean)
 
 # read in context info created by ssAlign module
 context_info = read.table(paste(out, "mods/modContext.txt", sep = ''),
                           header = TRUE)
-colnames(context_info) = c("isodecoder", "pos", "identity", "upstream", "downstream")
+colnames(context_info) = c("isodecoder", "canon_pos", "identity", "upstream", "downstream")
 context_info$isodecoder = sub(".*_mito_tRNA-", "mito", context_info$isodecoder)
 context_info$isodecoder = sub(".*_nmt_tRNA-", "nmt", context_info$isodecoder)
 context_info$isodecoder = sub(".*_tRNA-", "", context_info$isodecoder)
+context_info$isodecoder = sub(".*_tRX-", "tRX-", context_info$isodecoder)
 context_info$isodecoder = ifelse(context_info$isodecoder == "eColiLys-TTT-1-1",
                                  "eColiLys",
                                  context_info$isodecoder)
@@ -95,26 +97,35 @@ context_info$isodecoder = ifelse(context_info$isodecoder == "eColiLys-TTT-1-1",
 ###... make a scatter plot of misincorporation rates faceted by positions in cons_mods
 ### (selected known mod sites of interest) and by identity of nucleotide
 for (i in unique(mods_agg$condition)) {
-
+  
   # cyto mods
   sub_mods_agg = mods_agg[mods_agg$condition == i &
-                          !grepl("mito", mods_agg$isodecoder) &
-                          !grepl("nmt", mods_agg$isodecoder), ]
-  sub_mods_wide = dcast(sub_mods_agg[,c('isodecoder','pos', 'x')],
-                        list(.(isodecoder), .(pos)), value.var = 'x', 
+                            !grepl("mito", mods_agg$isodecoder) &
+                            !grepl("nmt", mods_agg$isodecoder), ]
+  sub_mods_wide = dcast(sub_mods_agg[,c('isodecoder','canon_pos', 'x')],
+                        list(.(isodecoder), .(canon_pos)), value.var = 'x', 
                         fun.aggregate = mean)
+  # add missing canon_pos columns
+  missing = cons_pos[!cons_pos %in% colnames(sub_mods_wide)]
+  sub_mods_wide[missing] = NaN
   sub_mods_wide[is.na(sub_mods_wide)] = 0
   rownames(sub_mods_wide) = sub_mods_wide$isodecoder
   sub_mods_wide = sub_mods_wide[, -1]
+  # sort these columns by cons_pos for correct order in heatmap
+  sub_mods_wide = sub_mods_wide[,cons_pos]
   sub_mods_mat = as.matrix(sub_mods_wide)
-  col_anno = HeatmapAnnotation(Mean = anno_barplot(aggregate(sub_mods_agg$x,
-                                                   by = list(pos = sub_mods_agg$pos),
-                                                   FUN = mean)$x,
+  col_anno_data = aggregate(sub_mods_agg$x,
+                            by = list(pos = sub_mods_agg$canon_pos),
+                            FUN = mean)
+  col_anno_data = rbind(col_anno_data, data.frame(pos = missing, x = 0))
+  col_anno_data = col_anno_data[match(cons_pos, col_anno_data$pos),]
+  col_anno_data = col_anno_data$x
+  col_anno = HeatmapAnnotation(Mean = anno_barplot(col_anno_data,
                                                    height = unit(1.5, 'cm'),
                                                    gp = gpar(fill = '#C8553D')))
   count_mods = sub_mods_agg %>% 
-               group_by(isodecoder) %>% 
-               summarise(count = sum(x > misinc_thresh))
+    group_by(isodecoder) %>% 
+    summarise(count = sum(x > misinc_thresh))
   row_anno = rowAnnotation(Count = row_anno_barplot(count_mods$count,
                                                     width = unit(1, 'cm'),
                                                     gp = gpar(fill = '#C8553D')))
@@ -133,24 +144,34 @@ for (i in unique(mods_agg$condition)) {
   
   # cyto stops
   sub_stops_agg = stops_agg[stops_agg$condition == i &
-                            !grepl("mito", stops_agg$isodecoder) &
-                            !grepl("nmt", stops_agg$isodecoder), ]
-  sub_stops_wide = dcast(sub_stops_agg[,c('isodecoder','pos', 'x')], 
-                        list(.(isodecoder), .(pos)), value.var = 'x', 
-                        fun.aggregate = mean)
+                              !grepl("mito", stops_agg$isodecoder) &
+                              !grepl("nmt", stops_agg$isodecoder), ]
+  sub_stops_wide = dcast(sub_stops_agg[,c('isodecoder','canon_pos', 'x')], 
+                         list(.(isodecoder), .(canon_pos)), value.var = 'x', 
+                         fun.aggregate = mean)
+  # add missing canon_pos columns
+  missing = cons_pos[!cons_pos %in% colnames(sub_stops_wide)]
+  sub_stops_wide[missing] = NaN
   sub_stops_wide[is.na(sub_stops_wide)] = 0
   rownames(sub_stops_wide) = sub_stops_wide$isodecoder
   sub_stops_wide = sub_stops_wide[, -1]
+  # sort these columns by cons_pos for correct order in heatmap
+  sub_stops_wide = sub_stops_wide[,cons_pos]
   sub_stops_mat = as.matrix(sub_stops_wide)
-  col_anno = HeatmapAnnotation(Mean = anno_barplot(aggregate(sub_stops_agg$x, 
-                                                             by = list(pos = sub_stops_agg$pos), 
-                                                             FUN = mean)$x, height = unit(1.5, 'cm'),
+  col_anno_data = aggregate(sub_stops_agg$x,
+                            by = list(pos = sub_stops_agg$canon_pos),
+                            FUN = mean)
+  col_anno_data = rbind(col_anno_data, data.frame(pos = missing, x = 0))
+  col_anno_data = col_anno_data[match(cons_pos, col_anno_data$pos),]
+  col_anno_data = col_anno_data$x
+  col_anno = HeatmapAnnotation(Mean = anno_barplot(col_anno_data,
+                                                   height = unit(1.5, 'cm'),
                                                    gp = gpar(fill = '#C8553D')))
   count_stops = sub_stops_agg %>%
-                group_by(isodecoder) %>%
-                summarise(count = sum(x > misinc_thresh))
+    group_by(isodecoder) %>%
+    summarise(count = sum(x > misinc_thresh))
   row_anno = rowAnnotation(Count = row_anno_barplot(count_stops$count, width = unit(1, 'cm'),
-                                                  gp = gpar(fill = '#C8553D')))
+                                                    gp = gpar(fill = '#C8553D')))
   cyto_stops_hm = Heatmap(sub_stops_mat,
                           column_labels = cons_pos,
                           row_title = "RT stops",
@@ -162,7 +183,7 @@ for (i in unique(mods_agg$condition)) {
                           heatmap_legend_param = 
                             list(title = "RT stop proportion",
                                  direction = "horizontal"))
-
+  
   # combined cyto heatmap
   heatmap_list = cyto_stops_hm %v% cyto_mods_hm
   pdf(paste(out, 'mods/', paste(i, "comb_heatmap.pdf", sep = "_"), 
@@ -170,31 +191,40 @@ for (i in unique(mods_agg$condition)) {
       width = 18, height = 16)
   draw(heatmap_list, ht_gap = unit(10, "mm"),
        column_title = "Cytoplasmic clusters")
-
+  
   if (!is.na(mito_trnas)) {
     # mito mods
     sub_mods_agg = mods_agg[mods_agg$condition == i &
-                           (grepl("mito", mods_agg$isodecoder) |
-                            grepl("nmt", mods_agg$isodecoder)), ]
-
+                              (grepl("mito", mods_agg$isodecoder) |
+                                 grepl("nmt", mods_agg$isodecoder)), ]
+    
     if (nrow(sub_mods_agg) != 0) {
-      sub_mods_wide = dcast(sub_mods_agg[,c('isodecoder','pos', 'x')],
-                            list(.(isodecoder), .(pos)), value.var = 'x',
+      sub_mods_wide = dcast(sub_mods_agg[,c('isodecoder','canon_pos', 'x')],
+                            list(.(isodecoder), .(canon_pos)), value.var = 'x',
                             fun.aggregate = mean)
+      # add missing canon_pos columns
+      missing = cons_pos[!cons_pos %in% colnames(sub_mods_wide)]
+      sub_mods_wide[missing] = NaN
       sub_mods_wide[is.na(sub_mods_wide)] = 0
       rownames(sub_mods_wide) = sub_mods_wide$isodecoder
       sub_mods_wide = sub_mods_wide[, -1]
+      # sort these columns by cons_pos for correct order in heatmap
+      sub_mods_wide = sub_mods_wide[,cons_pos]
       sub_mods_mat = as.matrix(sub_mods_wide)
-      col_anno = HeatmapAnnotation(Mean = anno_barplot(aggregate(sub_mods_agg$x,
-                                                       by = list(pos = sub_mods_agg$pos),
-                                                       FUN = mean)$x,
-                                          height = unit(1.5, 'cm'),  
-                                          gp = gpar(fill = '#C8553D')))
+      col_anno_data = aggregate(sub_mods_agg$x,
+                                by = list(pos = sub_mods_agg$canon_pos),
+                                FUN = mean)
+      col_anno_data = rbind(col_anno_data, data.frame(pos = missing, x = 0))
+      col_anno_data = col_anno_data[match(cons_pos, col_anno_data$pos),]
+      col_anno_data = col_anno_data$x
+      col_anno = HeatmapAnnotation(Mean = anno_barplot(col_anno_data,
+                                                       height = unit(1.5, 'cm'),  
+                                                       gp = gpar(fill = '#C8553D')))
       count_mods = sub_mods_agg %>%
-                   group_by(isodecoder) %>%
-                   summarise(count = sum(x > misinc_thresh))
+        group_by(isodecoder) %>%
+        summarise(count = sum(x > misinc_thresh))
       row_anno = rowAnnotation(Count = row_anno_barplot(count_mods$count, width = unit(1, 'cm'),
-                                                      gp = gpar(fill = '#C8553D')))
+                                                        gp = gpar(fill = '#C8553D')))
       mito_mods_hm = Heatmap(sub_mods_mat,
                              column_labels = cons_pos,
                              row_title = "Misincorporations",
@@ -207,26 +237,35 @@ for (i in unique(mods_agg$condition)) {
                              right_annotation = row_anno,
                              heatmap_legend_param = list(title = "Misincorporation proportion",
                                                          direction = "horizontal"))
-    
+      
       # mito stops
       sub_stops_agg = stops_agg[stops_agg$condition == i &
-                                (grepl("mito", stops_agg$isodecoder) |
-                                grepl("nmt", stops_agg$isodecoder)), ]
-      sub_stops_wide = dcast(sub_stops_agg[,c('isodecoder','pos', 'x')],
-                             list(.(isodecoder), .(pos)), value.var = 'x',
+                                  (grepl("mito", stops_agg$isodecoder) |
+                                     grepl("nmt", stops_agg$isodecoder)), ]
+      sub_stops_wide = dcast(sub_stops_agg[,c('isodecoder','canon_pos', 'x')],
+                             list(.(isodecoder), .(canon_pos)), value.var = 'x',
                              fun.aggregate = mean)
+      # add missing canon_pos columns
+      missing = cons_pos[!cons_pos %in% colnames(sub_stops_wide)]
+      sub_stops_wide[missing] = NaN
       sub_stops_wide[is.na(sub_stops_wide)] = 0
       rownames(sub_stops_wide) = sub_stops_wide$isodecoder
       sub_stops_wide = sub_stops_wide[, -1]
+      # sort these columns by cons_pos for correct order in heatmap
+      sub_stops_wide = sub_stops_wide[,cons_pos]
       sub_stops_mat = as.matrix(sub_stops_wide)
-      col_anno = HeatmapAnnotation(Mean = anno_barplot(aggregate(sub_stops_agg$x,
-                                                                 by = list(pos = sub_stops_agg$pos),
-                                                                 FUN = mean)$x,
+      col_anno_data = aggregate(sub_stops_agg$x,
+                                by = list(pos = sub_stops_agg$canon_pos),
+                                FUN = mean)
+      col_anno_data = rbind(col_anno_data, data.frame(pos = missing, x = 0))
+      col_anno_data = col_anno_data[match(cons_pos, col_anno_data$pos),]
+      col_anno_data = col_anno_data$x
+      col_anno = HeatmapAnnotation(Mean = anno_barplot(col_anno_data,
                                                        height = unit(1.5, 'cm'),
                                                        gp = gpar(fill = '#C8553D')))
       count_stops = sub_stops_agg %>%
-                    group_by(isodecoder) %>%
-                    summarise(count = sum(x > misinc_thresh))
+        group_by(isodecoder) %>%
+        summarise(count = sum(x > misinc_thresh))
       row_anno = rowAnnotation(Count = row_anno_barplot(count_stops$count, width = unit(1, 'cm'),
                                                         gp = gpar(fill = '#C8553D')))
       mito_stops_hm = Heatmap(sub_stops_mat,
@@ -239,7 +278,7 @@ for (i in unique(mods_agg$condition)) {
                               right_annotation = row_anno,
                               heatmap_legend_param = list(title = "RT stop proportion",
                                                           direction = "horizontal"))
-
+      
       # combined mito heatmap
       heatmap_list = mito_stops_hm %v% mito_mods_hm
       draw(heatmap_list,
@@ -248,63 +287,63 @@ for (i in unique(mods_agg$condition)) {
       dev.off()
     }
   }
-
+  
   else {
     dev.off()
   }
-
+  
   ### scatter plots ###
-  temp_mods = merge(mods, context_info, by = c("isodecoder", "pos"))
+  temp_mods = merge(mods, context_info, by = c("isodecoder", "canon_pos"))
   temp_mods = temp_mods %>%
-              group_by(isodecoder, pos, bam, identity) %>%
-              mutate(new_prop = proportion/sum(proportion))
+    group_by(isodecoder, canon_pos, bam, identity) %>%
+    mutate(new_prop = proportion/sum(proportion))
   filter_proportions = temp_mods %>%
-                       group_by(isodecoder, pos, bam, identity) %>%
-                       filter((any(max(new_prop) > 0.95) &
-                               any(canon_pos != 34)) |
-                              (any(max(new_prop) > 0.95) &
-                               any(identity != 'A') &
-                               any(canon_pos == 34) & any(type != "G")))
+    group_by(isodecoder, canon_pos, bam, identity) %>%
+    filter((any(max(new_prop) > 0.95) &
+              any(canon_pos != 34)) |
+             (any(max(new_prop) > 0.95) &
+                any(identity != 'A') &
+                any(canon_pos == 34) & any(type != "G")))
   sub_mods_agg = mods_agg[mods_agg$condition == i, ]
   sub_mods_pos = sub_mods_agg[sub_mods_agg$canon_pos %in% mod_sites, ]
   sub_mods_pos[which(sub_mods_pos$x > 1), "x"] = 1
-  sub_mods_pos = merge(sub_mods_pos, context_info, by = c("isodecoder", "pos"))
+  sub_mods_pos = merge(sub_mods_pos, context_info, by = c("isodecoder", "canon_pos"))
   sub_mods_pos = anti_join(sub_mods_pos,
-                          filter_proportions,
-                          by = c("isodecoder", "pos", "identity"))
+                           filter_proportions,
+                           by = c("isodecoder", "canon_pos", "identity"))
   names(sub_mods_pos)[names(sub_mods_pos) == "x"] = "Proportion"
-
+  
   sub_mods_pos$canon_pos = factor(sub_mods_pos$canon_pos,
                                   levels = c('9','20', '20a', '26', '32','34','37','58'))
-
+  
   mods_scatter = ggplot(sub_mods_pos[!grepl("mito", sub_mods_pos$isodecoder) &
-                                     !grepl("nmt", sub_mods_pos$isodecoder), ],
+                                       !grepl("nmt", sub_mods_pos$isodecoder), ],
                         aes(x=as.character(canon_pos),
                             y = Proportion,
                             color = Proportion)) +
-                 geom_jitter(width = 0.1, size = 3) +
-                 theme_bw() +
-                 facet_grid(identity~canon_pos, scales = "free_x", labeller = label_both) +
-                 scale_color_gradientn(breaks = c(0.0, 0.25, 0.50, 0.75, 1.0), colours = cols) +
-                 geom_hline(yintercept = misinc_thresh, linetype = "dashed", alpha = 0.4) +
-                 theme(
-                      axis.text.x = element_blank(),
-                      axis.title.x = element_blank(),
-                      axis.ticks.x = element_blank()
-                      )
+    geom_jitter(width = 0.1, size = 3) +
+    theme_bw() +
+    facet_grid(identity~canon_pos, scales = "free_x", labeller = label_both) +
+    scale_color_gradientn(breaks = c(0.0, 0.25, 0.50, 0.75, 1.0), colours = cols) +
+    geom_hline(yintercept = misinc_thresh, linetype = "dashed", alpha = 0.4) +
+    theme(
+      axis.text.x = element_blank(),
+      axis.title.x = element_blank(),
+      axis.ticks.x = element_blank()
+    )
   
   ggsave(paste(out, "mods/", paste(i, "misincProps.pdf", sep = "_"),
-              sep = ""),
-        mods_scatter, height=10, width=14)
-
+               sep = ""),
+         mods_scatter, height=10, width=14)
+  
   if (!is.na(mito_trnas)) {
     sub_mods_pos_mito = sub_mods_pos[grepl("mito", sub_mods_pos$isodecoder) |
-                                     grepl("nmt", sub_mods_pos$isodecoder), ]
-
+                                       grepl("nmt", sub_mods_pos$isodecoder), ]
+    
     if (nrow(sub_mods_pos_mito) != 0) {
       mito_mods_scatter = ggplot(sub_mods_pos_mito, 
-      aes(x=as.character(canon_pos), y = Proportion, color = Proportion)) + 
-      geom_jitter(width = 0.1, size = 3) +
+                                 aes(x=as.character(canon_pos), y = Proportion, color = Proportion)) + 
+        geom_jitter(width = 0.1, size = 3) +
         theme_bw() + 
         facet_grid(identity~canon_pos, scales = "free_x", labeller = label_both) + 
         scale_color_gradientn(breaks = c(0.0, 0.25, 0.50, 0.75, 1.0), colours = cols) +
@@ -315,11 +354,11 @@ for (i in unique(mods_agg$condition)) {
           axis.ticks.x=element_blank()
         )
       ggsave(paste(out, "mods/", paste('mito', i, 'misincProps.pdf', sep = '_'),
-            sep = ''),
-            mito_mods_scatter, height=10, width=14)
+                   sep = ''),
+             mito_mods_scatter, height=10, width=14)
     }
   }
-
+  
   ### Misinc signatures ###
   # create filter list of rows where total misinc. rate < misinc_thresh
   filter_misincthresh = sub_mods_agg[sub_mods_agg$x < misinc_thresh, ]
@@ -327,35 +366,35 @@ for (i in unique(mods_agg$condition)) {
   sub_mods_aggtype = mods[mods$condition == i, ]
   # use filter to filter rows from this table
   sub_mods_aggtype = anti_join(sub_mods_aggtype,
-                              filter_misincthresh,
-                              by = c("isodecoder", "pos"))
+                               filter_misincthresh,
+                               by = c("isodecoder", "canon_pos"))
   # add in context info
   sub_mods_aggtype = merge(sub_mods_aggtype,
-                          context_info,
-                          by = c("isodecoder", "pos"))
+                           context_info,
+                           by = c("isodecoder", "canon_pos"))
   sub_mods_aggtype$bam = sub(out, "", sub_mods_aggtype$bam)
   sub_mods_aggtype_cyt = sub_mods_aggtype[!grepl("mito", sub_mods_aggtype$isodecoder) &
-                                          !grepl("nmt", sub_mods_aggtype$isodecoder), ]
+                                            !grepl("nmt", sub_mods_aggtype$isodecoder), ]
   # renormalise by sum of misinc at each site for each isodecoder in each bam file
   # this makes sum all misinc types = 1
   # additionally filter all clusters at each pos where misinc of highest nucl > 0.95
   sub_mods_aggtype_cyt = sub_mods_aggtype_cyt %>%
-                         group_by(isodecoder, pos, bam, identity) %>%
-                         mutate(new_prop = proportion/sum(proportion)) %>%
-                         filter(any(max(new_prop) < 0.95) |
-                               (any(max(new_prop) >= 0.95 &
-                                any(identity == 'A') &
-                                any(canon_pos == 34) &
-                                any(type == 'G'))))
-
+    group_by(isodecoder, canon_pos, bam, identity) %>%
+    mutate(new_prop = proportion/sum(proportion)) %>%
+    filter(any(max(new_prop) < 0.95) |
+             (any(max(new_prop) >= 0.95 &
+                    any(identity == 'A') &
+                    any(canon_pos == 34) &
+                    any(type == 'G'))))
+  
   sub_mods_aggtype_cyt$canon_pos = factor(sub_mods_aggtype_cyt$canon_pos, 
                                           levels = c('9', '20', '20a','26','32','34','37','58'))
   color_num = length(unique(sub_mods_aggtype_cyt$bam)) + 1
   dot_colors = suppressMessages(brewer.pal(color_num, "Greys")[2:(color_num)])
   names(dot_colors) = unique(sub_mods_aggtype_cyt$bam)
-
+  
   signature_plot_upstream = ggplot(sub_mods_aggtype_cyt, 
-    aes(x = type, y = new_prop, fill = type)) + 
+                                   aes(x = type, y = new_prop, fill = type)) + 
     geom_jitter(aes(color = bam), alpha = 0.6, size = 0.7) +
     geom_boxplot(aes(color = type), lwd = 0.9, alpha = 0.4, outlier.shape = NA) +
     facet_grid(upstream~canon_pos+identity , scales = "free_x", labeller = label_both) + 
@@ -391,19 +430,19 @@ for (i in unique(mods_agg$condition)) {
   
   if (!is.na(mito_trnas)){
     sub_mods_aggtype_mito = sub_mods_aggtype[grepl("mito", sub_mods_aggtype$isodecoder) | grepl("nmt", sub_mods_aggtype$isodecoder), ]
-
+    sub_mods_aggtype_mito = sub_mods_aggtype_mito %>% group_by(isodecoder, canon_pos, bam) %>% mutate(new_prop = proportion/sum(proportion)) %>% filter(any(max(new_prop) < 0.95))
+    
     if(nrow(sub_mods_aggtype_mito) != 0) {
       # renormalise by sum of misinc at each site for each isodecoder in each bam file - this makes sum all misinc types = 1
-      sub_mods_aggtype_mito = sub_mods_aggtype_mito %>% group_by(isodecoder, pos, bam) %>% mutate(new_prop = proportion/sum(proportion)) %>% filter(any(max(new_prop) < 0.95))
       #sub_mods_aggtype_mito = aggregate(sub_mods_aggtype_mito$proportion, by = list(identity = sub_mods_aggtype_mito$identity, type = sub_mods_aggtype_mito$type, upstream = sub_mods_aggtype_mito$upstream, downstream = sub_mods_aggtype_mito$downstream, pos = sub_mods_aggtype_mito$pos, canon_pos=sub_mods_aggtype_mito$canon_pos), FUN = function(x) c(mean=mean(x), sd=sd(x)))
       #sub_mods_aggtype_mito = do.call("data.frame", sub_mods_aggtype_mito)
       sub_mods_aggtype_mito$canon_pos = factor(sub_mods_aggtype_mito$canon_pos, levels = c('9', '20', '20a', '26','32','34','37','58'))
-
+      
       # Reallocate bam dot colours to account for inconsistencies between mito and cyto bam numbers (usually due to very low count data)
       color_num = length(unique(sub_mods_aggtype_mito$bam)) + 1
       dot_colors = suppressMessages(brewer.pal(color_num, "Greys")[2:(color_num)])
       names(dot_colors) = unique(sub_mods_aggtype_mito$bam)
-
+      
       mito_signature_plot_upstream = ggplot(sub_mods_aggtype_mito, aes(x = type, y = new_prop, fill = type)) + 
         geom_jitter(aes(color = bam), alpha = 0.6, size = 0.7) +
         geom_boxplot(aes(color = type), lwd = 0.9, alpha = 0.4, outlier.shape = NA) +
@@ -418,9 +457,9 @@ for (i in unique(mods_agg$condition)) {
         scale_color_manual(values = c("A"="#739FC2", "C"="#7DB0A9", "G"="#9F8FA9", "T"="#C1B098", dot_colors)) +
         scale_fill_manual(values = c("#739FC2", "#7DB0A9", "#9F8FA9", "#C1B098")) +
         guides(color = "none", fill = guide_legend(override.aes = list(color = c("#739FC2", "#7DB0A9", "#9F8FA9", "#C1B098"))))
-
+      
       ggsave(paste(out, "mods/", paste("mito", i, 'misincSignatures_upstreamContext.pdf', sep = '_'), sep = ''), mito_signature_plot_upstream, height=10, width=14)
-
+      
       mito_signature_plot_downstream = ggplot(sub_mods_aggtype_mito, aes(x = type, y = new_prop, fill = type)) + 
         geom_jitter(aes(color = bam), alpha = 0.6, size = 0.7) +
         geom_boxplot(aes(color = type), lwd = 0.9, alpha = 0.4, outlier.shape = NA) +
@@ -435,7 +474,7 @@ for (i in unique(mods_agg$condition)) {
         scale_color_manual(values = c("A"="#739FC2", "C"="#7DB0A9", "G"="#9F8FA9", "T"="#C1B098", dot_colors)) +
         scale_fill_manual(values = c("#739FC2", "#7DB0A9", "#9F8FA9", "#C1B098")) +
         guides(color = "none", fill = guide_legend(override.aes = list(color = c("#739FC2", "#7DB0A9", "#9F8FA9", "#C1B098"))))
-
+      
       ggsave(paste(out, "mods/", paste("mito", i, 'misincSignatures_downstreamContext.pdf', sep = '_'), sep = ''), mito_signature_plot_downstream, height=10, width=14)
     }
   }
@@ -446,9 +485,25 @@ for (i in unique(mods_agg$condition)) {
 
 if (length(unique(mods$condition)) > 1) {
   dir.create(file.path(paste(out,"mods_logOR/", sep="/")), showWarnings = FALSE)
-
+  
   # Plots for logOR between conditions, including significance tests for each OR with chi-squared tests
+  
+  # read in all known and predicted mods from mimseq to filter heatmap for these sites only
+  # reduces noise at potentially unmodified sites
+  allmods = read.table(paste(out, "mods/allModsTable.csv", sep = ''), sep = "\t", header=T)
+  allmods = allmods[,c('isodecoder', 'canon_pos')]
+  allmods = allmods[!grepl("mito", allmods$isodecoder),]
+  allmods$isodecoder = sub(".*_tRNA-", "", allmods$isodecoder)
+  allmods$isodecoder = sub(".*_tRX-", "tRX-", allmods$isodecoder)
 
+  predictedmods = read.table(paste(out, "mods/predictedMods.csv", sep = ''), sep = "\t", header=T)
+  predictedmods = predictedmods[,c('isodecoder','canon_pos')]
+  predictedmods = predictedmods[!grepl("mito", predictedmods$isodecoder),]
+  predictedmods$isodecoder = sub(".*_tRNA-", "", predictedmods$isodecoder)
+  predictedmods$isodecoder = sub(".*_tRX-", "tRX-", predictedmods$isodecoder)
+
+  knownmods = rbind(allmods, predictedmods)
+  
   # modify mods and aggregate for total misinc. (sum of all types) and by condition (mean)
   mods$cov[is.na(mods$cov)] = 0
   mods = mods[!grepl("eColiLys", mods$isodecoder), ]
@@ -461,13 +516,13 @@ if (length(unique(mods$condition)) > 1) {
                                                   condition = mods$condition,
                                                   canon_pos = mods$canon_pos,
                                                   cov = mods$cov),
-                                                  FUN = sum)
+                       FUN = sum)
   mods_agg = aggregate(mods_agg$x, by = list(isodecoder = mods_agg$isodecoder,
                                              pos = mods_agg$pos,
                                              condition = mods_agg$condition,
                                              canon_pos = mods_agg$canon_pos,
                                              cov = mods_agg$cov), FUN = mean)
-
+  
   # for each condition make a misincorporation matrix
   mods_hm_list = list()
   stops_hm_list = list()
@@ -478,38 +533,44 @@ if (length(unique(mods$condition)) > 1) {
   for (i in unique(mods_agg$condition)) {
     # mods
     sub_mods_agg = subset(mods_agg, condition == i)
-    sub_mods_wide = dcast(sub_mods_agg[,c("isodecoder","pos", "x")],
-                         list(.(isodecoder), .(pos)), value.var = "x",
-                         fun.aggregate = mean)
-    sub_cov_wide = dcast(sub_mods_agg[,c("isodecoder","pos", "cov")],
-                         list(.(isodecoder), .(pos)), value.var = "cov",
+    sub_mods_wide = dcast(sub_mods_agg[,c("isodecoder","canon_pos", "x")],
+                          list(.(isodecoder), .(canon_pos)), value.var = "x",
+                          fun.aggregate = mean)
+    sub_cov_wide = dcast(sub_mods_agg[,c("isodecoder","canon_pos", "cov")],
+                         list(.(isodecoder), .(canon_pos)), value.var = "cov",
                          fun.aggregate = mean)
+    # add missing canon_pos columns
+    missing = cons_pos[!cons_pos %in% colnames(sub_mods_wide)]
+    sub_mods_wide[missing] = NaN
+    sub_cov_wide[missing] = NaN
     # convert NA to 0
     sub_mods_wide[is.na(sub_mods_wide)] = 0
     sub_cov_wide[is.na(sub_cov_wide)] = 0
     rownames(sub_mods_wide) = sub_mods_wide$isodecoder
     rownames(sub_cov_wide) = sub_cov_wide$isodecoder
     sub_mods_wide = sub_mods_wide[, -1]
+    sub_mods_wide = sub_mods_wide[,cons_pos]
     sub_mods_wide = as.matrix(sub_mods_wide)
     sub_cov_wide = sub_cov_wide[, -1]
+    sub_cov_wide = sub_cov_wide[,cons_pos]
     sub_cov_wide = as.matrix(sub_cov_wide)
-
+    
     # save mod proportion matrices
     mods_props[[i]] = sub_mods_wide
-
+    
     # get misincoproration as a value of coverage at each position
     sub_modCount_wide = sub_mods_wide * sub_cov_wide
     sub_unmodCount_wide = sub_cov_wide - sub_modCount_wide
     mods_mats[[i]] = sub_modCount_wide
     unmod_mats[[i]] = sub_unmodCount_wide
   }
-
+  
   # for each pairwise comparison of conditions, generate an log odds ratio heatmap (unload plyr to avoid errors)
   suppressWarnings(detach("package:plyr", unload=TRUE))
   mods_OR_list = list()
   mods_OR_hm = list()
   mods_OR_barplot = list()
-
+  
   ordered_levels = levels(lastlevel(unique(mods_agg$condition), control_cond))
   combinations = combn(ordered_levels, 2, simplify = FALSE)
   for (i in combinations) {
@@ -523,7 +584,7 @@ if (length(unique(mods$condition)) > 1) {
     mat2_mod = mods_mats[[second]]
     mat2_mod_props = mods_props[[second]]
     mat2_unmod = unmod_mats[[second]]
-
+    
     # make NA and 0 vlaues very small to stop inf errors when calculating log OR
     mat1_mod[is.na(mat1_mod)] = 0.0001
     mat1_mod_props[is.na(mat1_mod_props)] = 0.0001
@@ -559,16 +620,25 @@ if (length(unique(mods$condition)) > 1) {
     chisq = matrix(p.adjust(chisq, method = 'fdr'), nrow = nrow(temp))
     temp[chisq > 0.01 | foldchange < 0.25 | (mat1_mod_props < 0.1 & mat2_mod_props < 0.1)] = 0
     
+    # filter sites not in knownmods
+    for (i in rownames(temp)){
+      for (j in colnames(temp)){
+        if (plyr::empty(knownmods[(knownmods$isodecoder == i) & (knownmods$canon_pos == j),])) {
+          temp[i,j] = 0
+        }
+      }
+    }
+    
     # heatmaps
     # only draw if temp consists of something other than 0s
     if (length(temp[which(temp != 0)]) > 0) {
       col_fun = colorRamp2(c(max(abs(temp)), 0, -max(abs(temp))), c("#36682B", "#f7f7f7","#CC5803"))
       write.csv(temp, file=paste(out, "mods_logOR/", paste(comp,"logOR.csv",sep="_"), sep=""))
-    
+      
       pdf(paste(out, 'mods_logOR/', paste(comp, "logOR.pdf", sep = "_"), sep = ''), width = 14, height = 12)
       hm_logOR = Heatmap(temp, column_labels = cons_pos, column_title = as.character(comp), row_names_gp = gpar(fontsize = 6), column_names_gp = gpar(fontsize = 6), col = col_fun, column_title_side = "top", cluster_columns = FALSE, cluster_rows = TRUE, heatmap_legend_param = list(title = "Log odds ratio"))
       draw(hm_logOR)
       dev.off()
     }
   }
-}
+}
\ No newline at end of file
